this code is used for my learning, because other wheels are not enough or perfect
author: nwkami. init.py should put in a path named as your package name,and "name = "example_pkg""in it
again i move the code py into the path where init in.again add py_modules=['MyPakage.py'],in setup()